@@ -18,6 +18,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
+	"k8s.io/kubernetes/test/e2e/framework/pod"
+	e2epv "k8s.io/kubernetes/test/e2e/framework/pv"
 
 	buildv1 "github.com/openshift/api/build/v1"
 	exutil "github.com/openshift/origin/test/extended/util"
@@ -62,10 +64,10 @@ var _ = g.Describe("[Feature:Jenkins][Slow]jenkins repos e2e openshift using slo
 				exutil.DeletePVCsForDeployment(client, oc, "jenkins")
 				g.By("removing nfs pvs")
 				for _, pv := range pvs {
-					e2e.DeletePersistentVolume(client, pv.Name)
+					e2epv.DeletePersistentVolume(client, pv.Name)
 				}
 				g.By("removing nfs pod")
-				e2e.DeletePodWithWait(oc.AsAdmin().KubeFramework(), client, nfspod)
+				pod.DeletePodWithWait(client, nfspod)
 			}
 		}
 		setupJenkins = func(jenkinsTemplatePath string) {
