@@ -14,8 +14,8 @@ import (
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/util/validation"
 	"k8s.io/apimachinery/pkg/util/wait"
-	e2e "k8s.io/kubernetes/test/e2e/framework"
 	"k8s.io/kubernetes/test/e2e/framework/pod"
+	e2epv "k8s.io/kubernetes/test/e2e/framework/pv"
 
 	buildv1 "github.com/openshift/api/build/v1"
 	exutil "github.com/openshift/origin/test/extended/util"
@@ -51,6 +51,7 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 		secretPath                             = exutil.FixturePath("testdata", "openshift-secret-to-jenkins-credential.yaml")
 		successfulPipeline                     = exutil.FixturePath("testdata", "builds", "build-pruning", "successful-pipeline.yaml")
 		failedPipeline                         = exutil.FixturePath("testdata", "builds", "build-pruning", "failed-pipeline.yaml")
+		clientPluginPipelinePath               = exutil.FixturePath("..", "..", "examples", "jenkins", "pipeline", "openshift-client-plugin-pipeline.yaml")
 		multiNamespaceClientPluginPipelinePath = exutil.FixturePath("testdata", "multi-namespace-pipeline.yaml")
 		verifyServiceClientPluginPipelinePath  = exutil.FixturePath("testdata", "verifyservice-pipeline-template.yaml")
 		pollingInterval                        = time.Second
@@ -83,7 +84,7 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 				exutil.DeletePVCsForDeployment(client, oc, "jenkins")
 				g.By("removing nfs pvs")
 				for _, pv := range pvs {
-					e2e.DeletePersistentVolume(client, pv.Name)
+					e2epv.DeletePersistentVolume(client, pv.Name)
 				}
 				g.By("removing nfs pod")
 				pod.DeletePodWithWait(client, nfspod)
@@ -164,10 +165,9 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 			j = jenkins.NewRef(oc)
 
 			g.By("wait for jenkins to come up")
-			resp, err := j.WaitForContent("", 200, 5*time.Minute, "")
+			_, err = j.WaitForContent("", 200, 10*time.Minute, "")
 
 			if err != nil {
-				e2e.Logf("wait for jenkins to come up got err and resp string %s and err %s, dumping pods", resp, err.Error())
 				exutil.DumpApplicationPodLogs("jenkins", oc)
 			}
 
@@ -214,11 +214,66 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 	g.Context("jenkins-client-plugin tests", func() {
 
 		g.It("using the ephemeral template", func() {
+			g.Skip("disabling Jenkins until https://bugzilla.redhat.com/show_bug.cgi?id=1783530 sorted out")
 			defer cleanup(jenkinsEphemeralTemplatePath)
 			setupJenkins(jenkinsEphemeralTemplatePath)
 
 			g.By("Pipeline using jenkins-client-plugin")
 
+			g.By("should build and complete successfully", func() {
+				// instantiate the bc
+				g.By("create the jenkins pipeline strategy build config that leverages openshift client plugin")
+				err := oc.Run("create").Args("-f", clientPluginPipelinePath).Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+
+				// start the build - we run it twice because our sample pipeline exercises different paths of the client
+				// plugin based on whether certain resources already exist or not
+				for i := 0; i < 2; i++ {
+					g.By(fmt.Sprintf("starting the pipeline build and waiting for it to complete, pass: %d", i))
+					br, err := exutil.StartBuildAndWait(oc, "sample-pipeline-openshift-client-plugin")
+					if err != nil || !br.BuildSuccess {
+						debugAnyJenkinsFailure(br, oc.Namespace()+"-sample-pipeline-openshift-client-plugin", oc, true)
+						exutil.DumpBuilds(oc)
+						exutil.DumpBuildLogs("ruby", oc)
+						exutil.DumpDeploymentLogs("mongodb", 1, oc)
+						exutil.DumpDeploymentLogs("jenkins-second-deployment", 1, oc)
+						exutil.DumpDeploymentLogs("jenkins-second-deployment", 2, oc)
+					}
+					br.AssertSuccess()
+
+					g.By("get build console logs and see if succeeded")
+					_, err = j.GetJobConsoleLogsAndMatchViaBuildResult(br, "Finished: SUCCESS")
+					o.Expect(err).NotTo(o.HaveOccurred())
+				}
+
+				g.By("clean up openshift resources for next potential run")
+				err = oc.Run("delete").Args("bc", "sample-pipeline-openshift-client-plugin").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("dc", "jenkins-second-deployment").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("bc", "ruby").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("is", "ruby").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("is", "ruby-25-centos7").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+
+				// doing this as admin to avoid errors like this:
+				// Dec 14 13:13:02.275: INFO: Error running &{/usr/bin/oc [oc delete --config=/tmp/configfile590595709 --namespace=e2e-test-jenkins-pipeline-2z82q all -l template=mongodb-ephemeral-template] []   replicationcontroller "mongodb-1" deleted
+				// service "mongodb" deleted
+				// deploymentconfig.apps.openshift.io "mongodb" deleted
+				// Error from server (Forbidden): clusterserviceversions.operators.coreos.com is forbidden: User "e2e-test-jenkins-pipeline-2z82q-user" cannot list clusterserviceversions.operators.coreos.com in the namespace "e2e-test-jenkins-pipeline-2z82q": no RBAC policy matched
+				// Error from server (Forbidden): catalogsources.operators.coreos.com is forbidden: User "e2e-test-jenkins-pipeline-2z82q-user" cannot list catalogsources.operators.coreos.com in the namespace "e2e-test-jenkins-pipeline-2z82q": no RBAC policy matched
+				// Error from server (Forbidden): installplans.operators.coreos.com is forbidden: User "e2e-test-jenkins-pipeline-2z82q-user" cannot list installplans.operators.coreos.com in the namespace "e2e-test-jenkins-pipeline-2z82q": no RBAC policy matched
+				// Error from server (Forbidden): subscriptions.operators.coreos.com is forbidden: User "e2e-test-jenkins-pipeline-2z82q-user" cannot list subscriptions.operators.coreos.com in the namespace "e2e-test-jenkins-pipeline-2z82q": no RBAC policy matched
+				err = oc.AsAdmin().Run("delete").Args("all", "-l", "template=mongodb-ephemeral-template").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("template", "mongodb-ephemeral").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+				err = oc.Run("delete").Args("secret", "mongodb").Execute()
+				o.Expect(err).NotTo(o.HaveOccurred())
+			})
+
 			g.By("should verify services successfully", func() {
 				redisTemplate := "redis-ephemeral"
 				redisAppName := "redis"
@@ -326,6 +381,7 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 	g.Context("Sync plugin tests", func() {
 
 		g.It("using the ephemeral template", func() {
+			g.Skip("disabling Jenkins until https://bugzilla.redhat.com/show_bug.cgi?id=1783530 sorted out")
 			defer cleanup(jenkinsEphemeralTemplatePath)
 			setupJenkins(jenkinsEphemeralTemplatePath)
 
